@@ -20,7 +20,7 @@ typedef Eo Efl_Text_Markup_Util;
  */
 #define EFL_TEXT_MARKUP_UTIL_CLASS efl_text_markup_util_class_get()
 
-EWAPI const Efl_Class *efl_text_markup_util_class_get(void) EINA_CONST;
+EAPI EAPI_WEAK const Efl_Class *efl_text_markup_util_class_get(void) EINA_CONST;
 
 /**
  * @brief Converts a given (UTF-8) text to a markup-compatible string. This is
@@ -32,7 +32,7 @@ EWAPI const Efl_Class *efl_text_markup_util_class_get(void) EINA_CONST;
  *
  * @ingroup Efl_Text_Markup_Util
  */
-EOAPI char *efl_text_markup_util_text_to_markup(const char *text) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
+EAPI EAPI_WEAK char *efl_text_markup_util_text_to_markup(const char *text) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Converts a markup string to a (UTF-8) plain text. This is used mainly
@@ -44,7 +44,7 @@ EOAPI char *efl_text_markup_util_text_to_markup(const char *text) EFL_TRANSFER_O
  *
  * @ingroup Efl_Text_Markup_Util
  */
-EOAPI char *efl_text_markup_util_markup_to_text(const char *text) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
+EAPI EAPI_WEAK char *efl_text_markup_util_markup_to_text(const char *text) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
