@@ -25,6 +25,6 @@ typedef Eo Efl_Ui_Pager;
  */
 #define EFL_UI_PAGER_CLASS efl_ui_pager_class_get()
 
-EWAPI const Efl_Class *efl_ui_pager_class_get(void) EINA_CONST;
+EAPI EAPI_WEAK const Efl_Class *efl_ui_pager_class_get(void) EINA_CONST;
 
 #endif
